@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,28 +26,36 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_YY_HTML_H_INCLUDED
+# define YY_YY_HTML_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int yydebug;
+#endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     TEXT = 258,
-     COMMENT = 259,
-     START = 260,
-     END = 261,
-     NAME = 262,
-     STRING = 263,
-     PROCINS = 264,
-     EMPTYEND = 265,
-     DOCTYPE = 266,
-     ENDINCL = 267
-   };
+  enum yytokentype
+  {
+    TEXT = 258,
+    COMMENT = 259,
+    START = 260,
+    END = 261,
+    NAME = 262,
+    STRING = 263,
+    PROCINS = 264,
+    EMPTYEND = 265,
+    DOCTYPE = 266,
+    ENDINCL = 267
+  };
 #endif
 /* Tokens.  */
 #define TEXT 258
@@ -61,29 +69,25 @@
 #define DOCTYPE 266
 #define ENDINCL 267
 
-
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-
-/* Line 2068 of yacc.c  */
-#line 103 "html.y"
+#line 103 "html.y" /* yacc.c:1909  */
 
     string s;
     pairlist p;
 
-
-
-/* Line 2068 of yacc.c  */
-#line 81 "html.h"
-} YYSTYPE;
+#line 83 "html.h" /* yacc.c:1909  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
+int yyparse (void);
 
+#endif /* !YY_YY_HTML_H_INCLUDED  */
