@@ -40,7 +40,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 11 Apr 2000
- * Version: $Id: hxindex.c,v 1.21 2014-03-11 12:44:42 bbos Exp $
+ * Version: $Id: hxindex.c,v 1.22 2016/03/04 15:05:37 bbos Exp $
  *
  **/
 #include "config.h"
@@ -127,6 +127,8 @@ static bool final = false;	/* Leave used attributes in document */
 static bool trim_punct = true;	/* Remove trailing punctuation from terms */
 static string section_name = NULL; /* Term meaning "section %s" */
 static string unknown_name = NULL; /* Term meaning "without number" */
+static string* exclude_elts = NULL; /* Don't index these elements */
+static string* only_elts = NULL; /* Only index these elements */
 
 
 /* handle_error -- called when a parse error occurred */
@@ -738,6 +740,15 @@ static void copy_to_index(Tree t, Indexterm *terms, int importance,
   }
 }
 
+/* in_list -- check if word occurs in array list */
+static bool in_list(const string word, const string *list)
+{
+  int i;
+
+  for (i = 0; list[i]; i++) if (eq(word, list[i])) return true;
+  return false;
+}
+
 /* collect -- collect index terms, add IDs where needed */
 static void collect(Tree t, Indexterm *terms, string *secno, string *doctitle)
 {
@@ -761,6 +772,8 @@ static void collect(Tree t, Indexterm *terms, string *secno, string *doctitle)
 	  *secno = newstring(unknown_name);
 	}
 	if (eq(h->name, "dfn")) importance = 2;
+	else if (exclude_elts && in_list(h->name, exclude_elts)) importance = 0;
+	else if (only_elts && !in_list(h->name, only_elts)) importance = 0;
 	else if (has_class(h->attribs,INDEX)||has_class(h->attribs,INDEX_INST))
 	  importance = 1;
 	else if (userclassnames && has_class_in_list(h->attribs, userclassnames))
@@ -792,6 +805,7 @@ static void load_index(const string indexdb, Indexterm *terms)
 
   if (! (f = fopen(indexdb, "r"))) return;	/* Assume file not found... */
 
+  /* TODO: allow for arbitrarily long lines instead of MAXSTR */
   while (fgets(line, sizeof(line), f)) {
 #if 1
     n1 = strcspn(line, "\t");
@@ -917,7 +931,7 @@ int main(int argc, char *argv[])
 
   yyin = NULL;
 
-  while ((c = getopt(argc, argv, "txb:i:cnfrs:u:")) != -1)
+  while ((c = getopt(argc, argv, "txb:i:cnfrs:u:O:X:")) != -1)
   switch (c) {
   case 't': bctarget = false; break; /* Don't write <a name> after each ID */
   case 'x': xml = true; break;	/* Output as XML */
@@ -929,6 +943,8 @@ int main(int argc, char *argv[])
   case 'r': trim_punct = false; break; /* Do not remove trailing punctuation */
   case 's': section_name = newstring(optarg); break;
   case 'u': unknown_name = newstring(optarg); break;
+  case 'O': only_elts = tokenize(optarg); break; /* Index only these elements */
+  case 'X': exclude_elts = tokenize(optarg); break; /* Don't index these */
   default: usage(argv[0]);
   }
   if (optind == argc) yyin = stdin;
