@@ -20,7 +20,7 @@
  * Author: Bert Bos <bert@w3.org>
  * Created: 7 March 1999
  *
- * Copyright © 1994-2011 World Wide Web Consortium
+ * Copyright © 1999-2017 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
  *
@@ -237,7 +237,8 @@ static CURLcode wait_for_data(URL_FILE *file, size_t want)
     do rc = curl_multi_perform(multi_handle, &file->still_running);
     while (rc == CURLM_CALL_MULTI_PERFORM);
 
-    if (rc != CURLM_OK) return rc; /* Error */
+    if (rc == CURLM_OUT_OF_MEMORY) return CURLE_OUT_OF_MEMORY;
+    if (rc != CURLM_OK) errexit("Error waiting for data (%d)\n", rc);
 
     /* Stop if the connection is closed, after checking why */
     if (!file->still_running) {
@@ -264,7 +265,8 @@ static CURLcode wait_for_data(URL_FILE *file, size_t want)
     FD_ZERO(&fdexcep);
     maxfd = -1;
     rc = curl_multi_fdset(multi_handle, &fdread, &fdwrite, &fdexcep, &maxfd);
-    if (rc != CURLM_OK) return rc;
+    if (rc == CURLM_OUT_OF_MEMORY) return CURLE_OUT_OF_MEMORY;
+    if (rc != CURLM_OK) errexit("Error waiting for data (%d)\n", rc);
 
     /* Call select() to wait for either some data or a timeout */
     if (select(maxfd + 1, &fdread, &fdwrite, &fdexcep, &timeout) < 0)
@@ -336,7 +338,8 @@ EXPORT FILE *fopenurl3(const conststring method, const conststring url,
   const char *h, *v, *headerline;
   cookie_io_functions_t iofuncs;
   URL_FILE *file;
-  CURLcode rc;
+  CURLMcode rc;
+  CURLcode result;
   int dummy;
   size_t n;
 
@@ -428,12 +431,12 @@ EXPORT FILE *fopenurl3(const conststring method, const conststring url,
 #endif
 
   /* Get the first data, i.e., after any headers */
-  rc = wait_for_data(file, 1);
+  result = wait_for_data(file, 1);
 
-  if (rc != CURLM_OK) {
+  if (result != CURLE_OK) {
     free_file(file);
-    if (rc == CURLE_TOO_MANY_REDIRECTS) errno = EMLINK;
-    else if (rc == CURLE_UNSUPPORTED_PROTOCOL) errno = EPROTONOSUPPORT;
+    if (result == CURLE_TOO_MANY_REDIRECTS) errno = EMLINK;
+    else if (result == CURLE_UNSUPPORTED_PROTOCOL) errno = EPROTONOSUPPORT;
     else errno = EIO;
     return NULL;}
   /* Todo: make errno more specific, if possible */
